@@ -1,19 +1,22 @@
 use super::VmApiImpl;
 use elrond_wasm::{
-    api::{CryptoApi, CryptoApiImpl, Handle},
-    types::{BoxedBytes, MessageHashType},
+    api::{CryptoApi, CryptoApiImpl},
+    types::{heap::BoxedBytes, MessageHashType},
 };
 
 extern "C" {
     // managed buffer API
+    #[cfg(feature = "ei-1-1")]
     fn mBufferNew() -> i32;
 
     fn sha256(dataOffset: *const u8, length: i32, resultOffset: *mut u8) -> i32;
 
+    #[cfg(feature = "ei-1-1")]
     fn managedSha256(inputHandle: i32, outputHandle: i32) -> i32;
 
     fn keccak256(dataOffset: *const u8, length: i32, resultOffset: *mut u8) -> i32;
 
+    #[cfg(feature = "ei-1-1")]
     fn managedKeccak256(inputHandle: i32, outputHandle: i32) -> i32;
 
     fn ripemd160(dataOffset: *const u8, length: i32, resultOffset: *mut u8) -> i32;
@@ -78,7 +81,8 @@ impl CryptoApiImpl for VmApiImpl {
         }
     }
 
-    fn sha256(&self, data_handle: Handle) -> Handle {
+    #[cfg(feature = "ei-1-1")]
+    fn sha256(&self, data_handle: elrond_wasm::api::Handle) -> elrond_wasm::api::Handle {
         unsafe {
             let result_handle = mBufferNew();
             managedSha256(data_handle, result_handle);
@@ -95,7 +99,8 @@ impl CryptoApiImpl for VmApiImpl {
         }
     }
 
-    fn keccak256(&self, data_handle: Handle) -> Handle {
+    #[cfg(feature = "ei-1-1")]
+    fn keccak256(&self, data_handle: elrond_wasm::api::Handle) -> elrond_wasm::api::Handle {
         unsafe {
             let result_handle = mBufferNew();
             managedKeccak256(data_handle, result_handle);
