@@ -12,10 +12,10 @@ mod storage_api_node;
 mod unsafe_buffer;
 mod vm_api_node;
 
-#[cfg(not(feature = "unmanaged-ei"))]
+#[cfg(not(feature = "ei-unmanaged"))]
 mod send_api_node_impl_managed;
 
-#[cfg(feature = "unmanaged-ei")]
+#[cfg(feature = "ei-unmanaged")]
 mod send_api_node_impl_legacy;
 
 pub use vm_api_node::VmApiImpl;
